{% extends "admin_tools/dashboard/module.html" %}
{% block module_content %}
<ul class="{{ module.layout }}">
    {% spaceless %}
    {% for child in module.children %}
    <li class="{% cycle 'odd' 'even' %}">
    <a{{ child.attrs|safe }}>{{ child.title|capfirst }}</a> 
    </li>
    {% endfor %}
    {% endspaceless %}
</ul>
{% endblock %}
